@@ -15,6 +15,10 @@ class HowTo(blocks.StructBlock):
     name = blocks.CharBlock(required=True)
     description = blocks.CharBlock(required=True)
     image = ImageChooserBlock(label="Image 500x500", required=True)
+    total_time = blocks.CharBlock(required=True)
+    tool = blocks.CharBlock(required=True)
+    supply = blocks.CharBlock(required=True)
+
     step = blocks.StreamBlock(
         [
             ('step', HowToStep()),
