@@ -16,7 +16,7 @@ views.serve.csrf_exempt = True
 
 urlpatterns = [
     url(r'^robots\.txt$', robots),
-    url(r'^test$', error_404),
+    url(r'^404$', error_404),
     url(r'^sitemap\.xml$', sitemap),
     url(r'^worker(?P<version>.+).js$', worker),
     url(r'^admin_W3cJ32mq63V45CLvmjNbsqSJ32mq63V45CL/', admin.site.urls),
